# Generated by Django 4.0.7 on 2022-11-12 04:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("miningtaxes", "0003_alter_general_options"),
    ]

    operations = [
        migrations.AddField(
            model_name="settings",
            name="interest_rate",
            field=models.FloatField(
                default=5.0,
                verbose_name="Monthly interest rate (%) if taxes have not been paid",
            ),
        ),
        migrations.AlterField(
            model_name="settings",
            name="phrase",
            field=models.CharField(
                blank=True,
                default="",
                max_length=10,
                verbose_name="Keyword (case insensitive) that must be present in the donation reason to be counted. Leave blank/empty to count all donations regardless of reason.",
            ),
        ),
    ]
