# Generated by Django 4.0.7 on 2023-10-12 22:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("miningtaxes", "0010_stats_admin_get_all_activity_json"),
    ]

    operations = [
        migrations.AddField(
            model_name="stats",
            name="curmonth_leadergraph",
            field=models.JSONField(default=None, null=True),
        ),
    ]
