# Generated by Django 4.0.7 on 2022-11-14 02:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("miningtaxes", "0004_settings_interest_rate_alter_settings_phrase"),
    ]

    operations = [
        migrations.AddField(
            model_name="oreprices",
            name="raw_price",
            field=models.FloatField(default=0.0),
        ),
        migrations.AddField(
            model_name="oreprices",
            name="refined_price",
            field=models.FloatField(default=0.0),
        ),
        migrations.AddField(
            model_name="oreprices",
            name="taxed_price",
            field=models.FloatField(default=0.0),
        ),
    ]
