# Generated by Django 4.0.7 on 2023-05-28 00:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("miningtaxes", "0006_charactertaxcredits_credit_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="character",
            name="life_credits",
            field=models.FloatField(default=0.0),
        ),
        migrations.AddField(
            model_name="character",
            name="life_taxes",
            field=models.FloatField(default=0.0),
        ),
    ]
